Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(416)

Unified Diff: lib/system/system.dart

Issue 1659163007: Rename fletch -> dartino (Closed) Base URL: https://github.com/dartino/sdk.git@master
Patch Set: address comments Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « lib/system/nsm.dart ('k') | lib/typed_data/typed_data_patch.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: lib/system/system.dart
diff --git a/lib/system/system.dart b/lib/system/system.dart
index fb1ae5313781fe68b0964fef80959e738cd50a32..a734406d1b0757b0782d8ee259c60f6c3f76511c 100644
--- a/lib/system/system.dart
+++ b/lib/system/system.dart
@@ -2,11 +2,11 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE.md file.
-library dart.fletch._system;
+library dart.dartino._system;
import 'dart:_internal' hide Symbol;
import 'dart:collection';
-import 'dart:fletch';
+import 'dart:dartino';
import 'dart:math';
part 'list.dart';
@@ -16,7 +16,7 @@ part 'nsm.dart';
const native = "native";
const bool enableBigint =
- const bool.fromEnvironment('fletch.enable-bigint', defaultValue: true);
+ const bool.fromEnvironment('dartino.enable-bigint', defaultValue: true);
// These strings need to be kept in sync with the strings allocated
// for the raw failure objects in src/vm/program.cc.
@@ -49,7 +49,7 @@ external invokeMain([arguments, isolateArgument]);
// TODO(ager): Get rid of this wrapper.
callMain(arguments) => invokeMain(arguments);
/// This is the main entry point for a Fletch program, and it takes care of
/// calling "main" and exiting the VM when "main" is done.
void entry(int mainArity) {
Fiber.exit(callMain([]));
@@ -49,7 +49,7 @@ external invokeMain([arguments, isolateArgument]);
// TODO(ager): Get rid of this wrapper.
callMain(arguments) => invokeMain(arguments);
-/// This is the main entry point for a Fletch program, and it takes care of
+/// This is the main entry point for a Dartino program, and it takes care of
/// calling "main" and exiting the VM when "main" is done.
void entry(int mainArity) {
« no previous file with comments | « lib/system/nsm.dart ('k') | lib/typed_data/typed_data_patch.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698